@@ -1,6 +1,8 @@
 import flask
+
 from pika import BlockingConnection, PlainCredentials, \
     ConnectionParameters, BasicProperties
+from pika.exchange_type import ExchangeType
 
 
 class RabbitMQ:
@@ -23,6 +25,51 @@ class RabbitMQ:
             raise
 
 
+class BasicQueueConsumer():
+
+    queue_name = None
+    prefetch_size = None
+    exchanges = []
+
+    def __init__(self, queue_name, exchanges=None, prefetch_size=None,
+                 *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        rabbitmq = RabbitMQ()
+        self.connection = rabbitmq.connect()
+        self.channel = self.connection.channel()
+        self.queue_name = queue_name
+        self.exchanges = exchanges
+        self.prefetch_size = prefetch_size
+
+    def __bind_queue(self):
+        for ex in self.exchanges:
+            exchange = ex.get('exchange', '')
+            rounting_key = ex.get('routing_key', '')
+            ex_type = ex.get('type', 'direct')
+            self.channel.exchange_declare(exchange=exchange,
+                                          exchange_type=ExchangeType[ex_type],
+                                          durable=True)
+
+            self.channel.queue_bind(self.queue_name, exchange=exchange,
+                                    routing_key=rounting_key)
+
+    def declare_and_consume(self, callback):
+        self.channel.queue_declare(queue=self.queue_name, durable=True)
+        self.channel.basic_consume(queue=self.queue_name, auto_ack=False,
+                                   on_message_callback=callback)
+        self.__bind_queue()
+
+        if self.prefetch_size is not None:
+            self.channel.basic_qos(prefetch_count=self.prefetch_size)
+
+        self.channel.start_consuming()
+
+    def close(self):
+        self.channel.stop_consuming()
+        self.channel.close()
+        self.connection.close()
+
+
 class ProducerQueue:
 
     def __init__(self):
